@@ -1,5 +1,5 @@
 from ormar.fields.base import BaseField
-from ormar.fields.foreign_key import ForeignKey
+from ormar.fields.foreign_key import ForeignKey, UniqueColumns
 from ormar.fields.many_to_many import ManyToMany, ManyToManyField
 from ormar.fields.model_fields import (
     BigInteger,
@@ -13,6 +13,7 @@ from ormar.fields.model_fields import (
     String,
     Text,
     Time,
+    UUID,
 )
 
 __all__ = [
@@ -27,8 +28,10 @@ __all__ = [
     "Text",
     "Float",
     "Time",
+    "UUID",
     "ForeignKey",
     "ManyToMany",
     "ManyToManyField",
     "BaseField",
+    "UniqueColumns",
 ]
