@@ -9,6 +9,7 @@ from typing import (
     Mapping,
     Optional,
     Sequence,
+    Set,
     TYPE_CHECKING,
     Type,
     TypeVar,
@@ -23,6 +24,7 @@ from pydantic import BaseModel
 import ormar  # noqa I100
 from ormar.fields import BaseField
 from ormar.fields.foreign_key import ForeignKeyField
+from ormar.models.excludable import Excludable
 from ormar.models.metaclass import ModelMeta, ModelMetaclass
 from ormar.models.modelproxy import ModelTableProxy
 from ormar.relations.alias_manager import AliasManager
@@ -39,8 +41,17 @@ if TYPE_CHECKING:  # pragma no cover
     MappingIntStrAny = Mapping[IntStr, Any]
 
 
-class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass):
-    __slots__ = ("_orm_id", "_orm_saved", "_orm")
+class NewBaseModel(
+    pydantic.BaseModel, ModelTableProxy, Excludable, metaclass=ModelMetaclass
+):
+    __slots__ = (
+        "_orm_id",
+        "_orm_saved",
+        "_orm",
+        "_related_names",
+        "_related_names_hash",
+        "_props",
+    )
 
     if TYPE_CHECKING:  # pragma no cover
         __model_fields__: Dict[str, Type[BaseField]]
@@ -53,6 +64,10 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
         __database__: databases.Database
         _orm_relationship_manager: AliasManager
         _orm: RelationsManager
+        _orm_saved: bool
+        _related_names: Set
+        _related_names_hash: str
+        _props: List[str]
         Meta: ModelMeta
 
     # noinspection PyMissingConstructor
@@ -104,16 +119,20 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
             )
 
     def __setattr__(self, name: str, value: Any) -> None:  # noqa CCR001
-        if name in ("_orm_id", "_orm_saved", "_orm"):
+        if name in ("_orm_id", "_orm_saved", "_orm", "_related_names", "_props"):
             object.__setattr__(self, name, value)
         elif name == "pk":
             object.__setattr__(self, self.Meta.pkname, value)
+            self.set_save_status(False)
         elif name in self._orm:
             model = self.Meta.model_fields[name].expand_relationship(value, self)
             if isinstance(self.__dict__.get(name), list):
+                # virtual foreign key or many to many
                 self.__dict__[name].append(model)
             else:
+                # foreign key relation
                 self.__dict__[name] = model
+                self.set_save_status(False)
         else:
             value = (
                 self._convert_json(name, value, "dumps")
@@ -121,14 +140,22 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
                 else value
             )
             super().__setattr__(name, value)
+            self.set_save_status(False)
 
     def __getattribute__(self, item: str) -> Any:
-        if item in ("_orm_id", "_orm_saved", "_orm", "__fields__"):
+        if item in (
+            "_orm_id",
+            "_orm_saved",
+            "_orm",
+            "__fields__",
+            "_related_names",
+            "_props",
+        ):
             return object.__getattribute__(self, item)
-        if item != "extract_related_names" and item in self.extract_related_names():
-            return self._extract_related_model_instead_of_field(item)
         if item == "pk":
             return self.__dict__.get(self.Meta.pkname, None)
+        if item != "extract_related_names" and item in self.extract_related_names():
+            return self._extract_related_model_instead_of_field(item)
         if item != "__fields__" and item in self.__fields__:
             value = self.__dict__.get(item, None)
             value = self._convert_json(item, value, "loads")
@@ -166,6 +193,10 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
     def pk_column(self) -> sqlalchemy.Column:
         return self.Meta.table.primary_key.columns.values()[0]
 
+    @property
+    def saved(self) -> bool:
+        return self._orm_saved
+
     @classmethod
     def pk_type(cls) -> Any:
         return cls.Meta.model_fields[cls.Meta.pkname].__type__
@@ -177,18 +208,26 @@ class NewBaseModel(pydantic.BaseModel, ModelTableProxy, metaclass=ModelMetaclass
     def remove(self, name: "T") -> None:
         self._orm.remove_parent(self, name)
 
+    def set_save_status(self, status: bool) -> None:
+        object.__setattr__(self, "_orm_saved", status)
+
     @classmethod
     def get_properties(
         cls,
         include: Union["AbstractSetIntStr", "MappingIntStrAny"] = None,
         exclude: Union["AbstractSetIntStr", "MappingIntStrAny"] = None,
     ) -> List[str]:
-        props = [
-            prop
-            for prop in dir(cls)
-            if isinstance(getattr(cls, prop), property)
-            and prop not in ("__values__", "__fields__", "fields", "pk_column")
-        ]
+        if isinstance(cls._props, list):
+            props = cls._props
+        else:
+            props = [
+                prop
+                for prop in dir(cls)
+                if isinstance(getattr(cls, prop), property)
+                and prop
+                not in ("__values__", "__fields__", "fields", "pk_column", "saved")
+            ]
+            cls._props = props
         if include:
             props = [prop for prop in props if prop in include]
         if exclude:
